/*
 *  Copyright (C) 2008  Thadeu Lima de Souza Cascardo <cascardo@holoscopio.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */


#ifndef HC_XMPP_H
#define HC_XMPP_H

#include <iksemel.h>

enum
{
  HC_XMPP_NONE,
  HC_XMPP_AUTHENTICATED,
  HC_XMPP_BOUND,
  HC_XMPP_SESSION
};

typedef struct _hc_xmpp_t hc_xmpp_t;

#define HC_XMPP_NS_TLS "urn:ietf:params:xml:ns:xmpp-tls"
#define HC_XMPP_NS_SASL "urn:ietf:params:xml:ns:xmpp-sasl"
#define HC_XMPP_NS_BIND "urn:ietf:params:xml:ns:xmpp-bind"
#define HC_XMPP_NS_SESSION "urn:ietf:params:xml:ns:xmpp-session"
#define HC_XMPP_NS_DISCO "http://jabber.org/protocol/disco"
#define HC_XMPP_NS_DISCO_INFO "http://jabber.org/protocol/disco#info"

hc_xmpp_t * hc_xmpp_new (iksStreamHook *, char *, char *, char *);
int hc_xmpp_is_tls_supported (hc_xmpp_t *);
int hc_xmpp_is_tls_required (hc_xmpp_t *);
int hc_xmpp_is_tls_optional (hc_xmpp_t *);
int hc_xmpp_is_tls_enabled (hc_xmpp_t *);
int hc_xmpp_is_sasl_supported (hc_xmpp_t *);
int hc_xmpp_is_sasl_required (hc_xmpp_t *);
int hc_xmpp_is_sasl_optional (hc_xmpp_t *);
int hc_xmpp_is_sasl_enabled (hc_xmpp_t *);
int hc_xmpp_is_bind_supported (hc_xmpp_t *);
int hc_xmpp_is_session_supported (hc_xmpp_t *);
int hc_xmpp_is_session_required (hc_xmpp_t *);
char *hc_xmpp_server (hc_xmpp_t *);
int hc_xmpp_fd (hc_xmpp_t *);
void hc_xmpp_send_buffer (hc_xmpp_t *, char *, size_t);
void hc_xmpp_send_iks (hc_xmpp_t *, iks *);
void hc_xmpp_read_and_parse (hc_xmpp_t *);
void hc_xmpp_features (hc_xmpp_t *, iks *);
int hc_xmpp_status (hc_xmpp_t *);
int hc_xmpp_hook (void *, int, iks *);
void hc_xmpp_send_stream (hc_xmpp_t *);

#endif
